//AddDamageType("TacKnife",   '<color:0000FF>knifed<color:FF0000> %1',    '%2 <color:0000FF>knifed %1',0.75,1);

// ========================================
// The tac knife is an always useable knife choice, activated on right click.
// This allows different playertypes to use a knife that doesn't take up inventory space, and functions rather nicely.
// That is also why it has no item Datablock.
// ========================================

datablock AudioProfile(TacKnifeHitObjectSound)
{
   filename    = "./TacKnife_ObjectHit.wav";
   description = AudioClose3d;
   preload = true;
};

datablock AudioProfile(TacKnifeHitPlayerSound)
{
   filename    = "./TacKnife_PlayerHit.wav";
   description = AudioClose3d;
   preload = true;
};

datablock AudioProfile(TacKnifeSwingSound)
{
   filename    = "./TacKnife_Swing.wav";
   description = AudioClose3d;
   preload = true;
};

datablock ShapeBaseImageData(TacKnifeImage)
{
   shapeFile = "./knife.dts";
   emap = true;

   // Specify mount point & offset for 3rd person, and eye offset
   // for first person rendering.
   mountPoint = 1;
   offset = "0.0 0 0.0";
   rotation = eulerToMatrix("0 0 0");
   eyeOffset = "0";

   // When firing from a point offset from the eye, muzzle correction
   // will adjust the muzzle vector to point to the eye LOS point.
   // Since this weapon doesn't actually fire from the muzzle point,
   // we need to turn this off.  
   correctMuzzleVector = false;

   className = "TF2MeleeWeaponImage";

   // Projectile && Ammo.
   item = TacKnifeItem;
   ammo = " ";
   projectile = hammerProjectile;
   projectileType = Projectile;

   //melee particles shoot from eye node for consistancy
   melee = true;
   doRetraction = false;
   //raise your arm up or not
   armReady = true;

   //casing = " ";
   doColorShift = false;
   
   raycastWeaponRange = 3;
   raycastWeaponTargets = $TypeMasks::FxBrickObjectType |	//Targets the weapon can hit: Raycasting Bricks
   				$TypeMasks::PlayerObjectType |	//AI/Players
   				$TypeMasks::StaticObjectType |	//Static Shapes
   				$TypeMasks::TerrainObjectType;	//Terrain
   raycastExplosionProjectile = hammerProjectile;
   raycastExplosionBrickSound = TacKnifeHitObjectSound;
   raycastExplosionPlayerSound = TacKnifeHitPlayerSound;
   raycastDirectDamage = 205;
   raycastDirectDamageType = $DamageType::TacKnife;
   
   // Images have a state system which controls how the animations
   // are run, which sounds are played, script callbacks, etc. This
   // state system is downloaded to the client so that clients can
   // predict state changes and animate accordingly.  The following
   // system supports basic ready->fire->reload transitions as
   // well as a no-ammo->dryfire idle state.

   // Initial start up state
	stateName[0]			= "Equip";
	stateTimeoutValue[0]		= 0.2;
	stateTransitionOnTimeout[0]	= "Attack";
	stateScript[0]			= "onEquip";

	stateName[1]			= "Attack";
	stateTimeoutValue[1]		= 0.25;
	stateWaitForTimeout[1]		= true;
	stateSound[1]			= TacKnifeSwingSound;
	stateFire[1]			= true;
	stateSequence[1]		= "attack";
	stateScript[1]			= "onFire";
	stateTransitionOnTimeout[1]	= "UnEquip";

	stateName[2]			= "UnEquip";
	stateTimeoutValue[2]		= 0.2;
	stateScript[2]			= "onUnEquip";
};

function TafKnifeImage::onFire(%this, %obj, %slot)
{
	WeaponImage::onFire(%this, %obj, %slot);
}

function TacKnifeImage::OnMount(%this,%obj,%slot)
{
	Parent::OnMount(%this,%obj,%slot);

	%obj.hideNode("LHand");
	%obj.hideNode("LHook");

	%obj.playthread(1, armReadyLeft);

}

function TacKnifeImage::onUnMount(%this,%obj,%slot)
{
	Parent::onMount(%this,%obj,%slot);

	%obj.playthread(1, root);

	%obj.unHideNode("ALL");

	if(isObject(%obj.client))
	{
		%obj.client.applyBodyParts();
		%obj.client.applyBodyColors();
	}

	else
	{
		applyDefaultCharacterPrefs(%obj);
	}
}

function TacKnifeImage::onUnEquip(%this, %obj, %slot)
{
	%obj.unMountImage(0);
	%obj.unMountImage(1);
	
	if(%obj.oldItem != 0)
	{
		%obj.mountImage(%obj.oldItem, 0);
		%obj.playthread(1, armReadyRight);
	}
}

package TacKnifeUse
{
   function Armor::onTrigger(%this, %player, %slot, %val)
   {
      if(%player.getMountedImage(0) !$= TacKnifeImage.getID() && %player.getDatablock().usesTacKnife == 1 && %slot $= 4 && %val)
      {
         if(%player.lastKnife !$= "" && getSimTime() - %player.lastKnife < 1000)
         {
            return;
         }
	
	 if(%obj.isMounted())
		return;

	 %player.oldItem = %player.getMountedImage(0);

	 %player.mountImage(TacKnifeImage, 0);
	 %player.lastKnife = getSimTime();
      }
      Parent::onTrigger(%this, %player, %slot, %val);
   }
};   
ActivatePackage(TacKnifeUse);
